<?php class imagingsetting extends baseobject {
	
	protected static array $fields=array(
			'name'=>validator::REQUIRED,
			'imagingparametersversionid'=>array(validator::REQUIRED,validator::INTEGER),
			'imagerid'=>array(validator::REQUIRED,validator::INTEGER),
			'settingname'=>validator::REQUIRED,
			'settingvalue'=>validator::REQUIRED,
	);
	
	protected static array $helpTexts=array(
			'name'=>'A unique name for this combination of parameters version, imager and setting',
			'imagingparametersversionid'=>'The ID of the parameters version',
			'imagerid'=>'The imager',
			'settingname'=>'The parameter being set',
			'settingvalue'=>'The value of the setting in this particular set of parameters',
	);
	
}